<?php

namespace Drupal\entity_collector_downloader;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityManagerInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\entity_collector\Entity\EntityCollectionInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class TaxonomyViewsIntegratorPermissions
 *
 * @package Drupal\entity_collector_downloader
 */
class EntityCollectorDownloadAccess implements ContainerInjectionInterface {

  use StringTranslationTrait;

  /**
   * The entity manager.
   *
   * @var \Drupal\Core\Entity\EntityManagerInterface
   */
  protected $entityManager;

  /**
   * Constructs a TaxonomyViewsIntegratorPermissions instance.
   *
   * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
   *   The entity manager.
   */
  public function __construct(EntityManagerInterface $entity_manager) {
    $this->entityManager = $entity_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static($container->get('entity.manager'));
  }

  /**
   * Get permissions for Taxonomy Views Integrator.
   *
   * @return array
   *   Permissions array.
   */
  public function permissions() {
    $permissions = [];

    foreach ($this->entityManager->getStorage('entity_collector_type')->loadMultiple() as $entityCollectorType) {
      $permissions += [
        'access entity collection type ' . $entityCollectorType->id() . ' download page' => [
          'title' => $this->t('%entity_collection_type: Access entity collection download page', array('%entity_collection_type' => $entityCollectorType->label())),
        ]
      ];
    }

    return $permissions;
  }

  public function access(EntityCollectionInterface $entityCollection) {

  }
}
